.. seawater documentation master file, created by
   sphinx-quickstart on Tue Aug 10 16:47:25 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to gsw's documentation!
====================================

python gsw
==========

Introduction:
-------------
Python implementation of the Thermodynamic Equation Of Seawater - 2010
(TEOS-10)

For more information go to:
    http://www.teos-10.org/

Modules:
--------

.. toctree::
   :maxdepth: 4


gibbs Seawater Documentation
============================

This page contains the gsw Module documentation.

The :mod:`gibbs` module
-----------------------

.. automodule:: seawater.gibbs
    :members:
    :undoc-members:
    :show-inheritance:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
